@@ -1,8 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * Razor - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org
  *
  * Copyright: 2010-2011 Razor team
  * Authors:
@@ -105,7 +105,8 @@ void XdgMenuWidgetPrivate::init(const QDomElement& xml)
         title = xml.attribute(QLatin1String("name"));
     q->setTitle(escape(title));
 
-    q->setToolTip(xml.attribute(QLatin1String("comment")));
+    //q->setToolTip(xml.attribute(QLatin1String("comment")));
+    q->setToolTipsVisible(true);
 
 
     QIcon parentIcon;
@@ -221,12 +222,12 @@ XdgAction* XdgMenuWidgetPrivate::createAction(const QDomElement& xml)
     else
         title = xml.attribute(QLatin1String("name"));
 
+    action->setText(escape(title));
 
     if (!xml.attribute(QLatin1String("genericName")).isEmpty() &&
          xml.attribute(QLatin1String("genericName")) != title)
-        title += QString::fromLatin1(" (%1)").arg(xml.attribute(QLatin1String("genericName")));
+        action->setToolTip(xml.attribute(QLatin1String("genericName")));
 
-    action->setText(escape(title));
     return action;
 }
 
